summaryrefslogtreecommitdiffstats
path: root/source/slang/slang-ir-diff-call.cpp
diff options
context:
space:
mode:
authorYong He <yonghe@outlook.com>2022-10-27 12:19:30 -0700
committerGitHub <noreply@github.com>2022-10-27 12:19:30 -0700
commit0cbef6fd6d7924d37ef3ea5ec7c848c80947d13f (patch)
tree173fa18c39638e7d41ae092b9012554cb867a31b /source/slang/slang-ir-diff-call.cpp
parent351e78f3abc54f114237d4af64f8199476ebf176 (diff)
Rename `__jvp`-->`__fwd_diff`. (#2471)
Co-authored-by: Yong He <yhe@nvidia.com>
Diffstat (limited to 'source/slang/slang-ir-diff-call.cpp')
-rw-r--r--source/slang/slang-ir-diff-call.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/slang/slang-ir-diff-call.cpp b/source/slang/slang-ir-diff-call.cpp
index 3f2c6c789..34e7e3de0 100644
--- a/source/slang/slang-ir-diff-call.cpp
+++ b/source/slang/slang-ir-diff-call.cpp
@@ -34,8 +34,8 @@ struct DerivativeCallProcessContext
do
{
auto nextChild = child->getNextInst();
- // Look for IRJVPDifferentiate
- if (auto derivOf = as<IRJVPDifferentiate>(child))
+ // Look for IRForwardDifferentiate
+ if (auto derivOf = as<IRForwardDifferentiate>(child))
{
processDifferentiate(derivOf);
}
@@ -50,14 +50,14 @@ struct DerivativeCallProcessContext
// Perform forward-mode automatic differentiation on
// the intstructions.
- void processDifferentiate(IRJVPDifferentiate* derivOfInst)
+ void processDifferentiate(IRForwardDifferentiate* derivOfInst)
{
IRInst* jvpCallable = nullptr;
// First get base function
auto origCallable = derivOfInst->getBaseFn();
// Resolve the derivative function for IRJVPDifferentiate(IRSpecialize(IRFunc))
// Check the specialize inst for a reference to the derivative fn.
//
if (auto origSpecialize = as<IRSpecialize>(origCallable))
@@ -68,7 +68,7 @@ struct DerivativeCallProcessContext
}
}
// Resolve the derivative function for an IRJVPDifferentiate(IRFunc)
//
// Check for the 'JVPDerivativeReference' decorator on the
// base function.
@@ -50,14 +50,14 @@ struct DerivativeCallProcessContext
// First get base function
auto origCallable = derivOfInst->getBaseFn();
- // Resolve the derivative function for IRJVPDifferentiate(IRSpecialize(IRFunc))
+ // Resolve the derivative function for IRForwardDifferentiate(IRSpecialize(IRFunc))
// Check the specialize inst for a reference to the derivative fn.
//
@@ -68,7 +68,7 @@ struct DerivativeCallProcessContext
}
}
- // Resolve the derivative function for an IRJVPDifferentiate(IRFunc)
+ // Resolve the derivative function for an IRForwardDifferentiate(IRFunc)
//
// Check for the 'JVPDerivativeReference' decorator on the